@@ -1,14 +1,14 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "copilot" "0.3.0"
-  "An unofficial Copilot plugin."
+(define-package "copilot" "0.4.0"
+  "An Emacs plugin for GitHub Copilot."
   '((emacs         "27.2")
     (editorconfig  "0.8.2")
     (jsonrpc       "1.0.14")
-    (f             "0.20.0")
+    (compat        "30")
     (track-changes "1.4"))
   :url "https://github.com/copilot-emacs/copilot.el"
-  :commit "b98754712ad05282e1bb392bb35e5918ed35c9b6"
-  :revdesc "b98754712ad0"
+  :commit "7904f13d52e8dcda3af67142c42fa7c8345ba6fe"
+  :revdesc "7904f13d52e8"
   :keywords '("convenience" "copilot")
   :authors '(("zerol" . "z@zerol.me"))
   :maintainers '(("Jen-Chieh" . "jcs090218@gmail.com")
